<?php
/** 
 * PAYONE OXID Connector is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * PAYONE OXID Connector is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with PAYONE OXID Connector.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @link      http://www.payone.de
 * @copyright (C) Payone GmbH
 * @version   OXID eShop CE
 */
 
class fcPayOneViewConf extends fcPayOneViewConf_parent {
    
    /**
     * Name of the module folder
     * @var string
     */
    protected $_sModuleFolder = "fcPayOne";
    
    /**
     * Helper object for dealing with different shop versions
     * @var object
     */
    protected $_oFcpoHelper = null;

    /**
     * Hosted creditcard js url
     * 
     * @var string
     */
    protected $_sFcPoHostedJsUrl = 'https://secure.pay1.de/client-api/js/v1/payone_hosted_min.js';
    
    /**
     * Initializing needed things
     */
    public function __construct() {
        parent::__construct();
        $this->_oFcpoHelper = oxNew('fcpohelper');
    }
    
    
    /**
     * Returns the path to module
     * 
     * @param void
     * @return string
     */
    public function fcpoGetModulePath() {
        return $this->getModulePath($this->_sModuleFolder);
    }

    
    /**
     * Returns the url to module
     * 
     * @param void
     * @return string
     */
    public function fcpoGetModuleUrl() {
        return $this->getModuleUrl($this->_sModuleFolder);
    }
    
    
    /**
     * Returns url to module img folder (admin)
     * 
     * @param void
     * @return string
     */
    public function fcpoGetAdminModuleImgUrl() {
        $sModuleUrl         = $this->fcpoGetModuleUrl();
        $sModuleAdminImgUrl = $sModuleUrl.'out/admin/img/';
        
        return $sModuleAdminImgUrl;
    }
    
    
    /**
     * Returns the path to javascripts of module
     * 
     * @param string $sFile
     * @return string
     */
    public function fcpoGetAbsModuleJsPath( $sFile="" ) {
        $sModulePath        = $this->fcpoGetModulePath();
        $sModuleJsPath      = $sModulePath.'out/src/js/';
        if ( $sFile ) {
            $sModuleJsPath  = $sModuleJsPath.$sFile;
        }
        
        return $sModuleJsPath;
    }
    
    
    /**
     * Returns the path to javascripts of module
     * 
     * @param string $sFile
     * @return string
     */
    public function fcpoGetModuleJsPath( $sFile="" ) {
        $sModuleUrl         = $this->fcpoGetModuleUrl();
        $sModuleJsUrl       = $sModuleUrl.'out/src/js/';
        if ( $sFile ) {
            $sModuleJsUrl   = $sModuleJsUrl.$sFile;
        }
        
        return $sModuleJsUrl;
    }
    
    
    /**
     * Returns integer of shop version
     * 
     * @param void
     * @return string
     */
    public function fcpoGetIntShopVersion() {
        return $this->_oFcpoHelper->fcpoGetIntShopVersion();
    }
    
    /**
     * Returns the path to javascripts of module
     * 
     * @param string $sFile
     * @return string
     */
    public function fcpoGetModuleCssPath( $sFile="" ) {
        $sModuleUrl         = $this->fcpoGetModuleUrl();
        $sModuleUrl       = $sModuleUrl.'out/src/css/';
        if ( $sFile ) {
            $sModuleUrl   = $sModuleUrl.$sFile;
        }
        
        return $sModuleUrl;
    }
    
    /**
     * Returns the path to javascripts of module
     * 
     * @param string $sFile
     * @return string
     */
    public function fcpoGetAbsModuleTemplateFrontendPath( $sFile="" ) {
        $sModulePath        = $this->fcpoGetModulePath();
        $sModulePath      = $sModulePath.'application/views/frontend/tpl/';
        if ( $sFile ) {
            $sModulePath  = $sModulePath.$sFile;
        }
        
        return $sModulePath;
    }
    
    /**
     * Returns hosted js url
     * 
     * @return string
     */
    public function fcpoGetHostedPayoneJs() {
        return $this->_sFcPoHostedJsUrl;
    }
    
}
